# NStudyPy 
NStudyPy 工具包


## 使用方法
```bash
pip install -U NStudyPy -i https://pypi.org/simple
```

## 版本更新历史

## version 0.0.4
- Python 升级到 3.9+
- 添加 `PyShape` `PyString` 工具

## version 0.0.3
- 更改包名

## version 0.0.2
- 添加一些方法 `from NStudyPy import PyTools`

## version 0.0.1
- 初始化项目